#
# spec file for package gnome-2048
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-2048
Version:        3.38.2
Release:        2.13
Summary:        Sliding block puzzle game
License:        GPL-3.0-or-later
Group:          Amusements/Games/Board/Puzzle
URL:            https://wiki.gnome.org/Apps/2048
Source0:        https://download.gnome.org/sources/gnome-2048/3.38/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM 21.patch -- Fix build with meson 0.61 and newer
Patch0:         https://gitlab.gnome.org/GNOME/gnome-2048/-/merge_requests/21.patch

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  itstool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.24.0
BuildRequires:  pkgconfig(clutter-1.0) >= 1.12.0
BuildRequires:  pkgconfig(clutter-gtk-1.0) >= 1.6.0
BuildRequires:  pkgconfig(gee-0.8) >= 0.14.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(libgnome-games-support-1) >= 1.7.1

%description
2048 is a single-player sliding block puzzle game, in which the
objective is to slide and merge same-numbered tiles on a grid to
reach higher numbers.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}

%check
%meson_test

%files
%license COPYING
%{_bindir}/gnome-2048
%{_datadir}/metainfo/org.gnome.TwentyFortyEight.appdata.xml
%{_datadir}/applications/org.gnome.TwentyFortyEight.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.TwentyFortyEight.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.TwentyFortyEight*
%{_mandir}/man6/gnome-2048.6%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Feb  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 21.patch: Fix build with meson 0.61 and newer.
- Add desktop-file-utils and replace erronus appstream-glib-devel
  with appstream-glib BuildRequires, and add a check section and
  meson_test macro, run tests during build.
- Drop update-desktop-files BuildRequires and macro, no longer
  needed.
* Mon Nov 23 2020 dimstar@opensuse.org
- Update to version 3.38.2:
  + Updated translations.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Tue Sep  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.37.91:
  + Some rare bugs fixed (ghost tiles may have appeared when the
    grid was resized during a move, and the icon was missing in the
    Scores dialog)
- Changes from version 3.37.1:
  + Use event controllers.
  + Updated translations.
* Mon Jul  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.4:
  + Updated translations.
* Fri Jun  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.3:
  + Updated translations.
* Sat Apr 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Updated translations.
* Wed Mar 11 2020 mgorse@suse.com
- Update to version 3.36.0:
  + Updated translations.
* Fri Feb 14 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Updated translations.
- Changes from version 3.35.2:
  + Some command-line options were added: the usual “--version”,
    “--size” to start a new game of a given size (the exact
    behavior might change) and “--cli” for playing in a terminal.
  + The game window has been allowed to be resized to a phone
    screen, even if more work is needed.
* Fri Feb 14 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.5:
  + Metadata fixes.
  + Updated translations.
* Sat Nov 23 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.4:
  + Updated translations.
* Tue Oct 29 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.3:
  + New extra release for fixing a small visual bug introduced in
    3.34.2.
* Sun Oct 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Fix the icons showing in GNOME Shell 3.34.
* Tue Oct  8 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Updated translations.
* Thu Sep 12 2019 sckang@suse.com
- Update to version 3.34.0.
  + No changes, stable version update only.
* Tue Aug 27 2019 dimstar@opensuse.org
- Update to version 3.33.90:
  + Fix GameOver showing on resume.
  + A new icon.
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + An unfullscreen button was added.
  + First launch of the app immediatly starts on a new game.
  + Updated translations.
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Some crashes avoided, notably if loading a manually edited
    saved game file, and a better tiles look on non-square grids,
    that should be all the things important for users. From the
    technical side, the internal representation of the board
    changed, to make it less error-prone, and many parts of the
    code have moved around. Some tests were also added.
  + Updated translations.
- Changes from version 3.31.90:
  + Various changes. The main is probably the removing of the
    Preferences dialog: the Undo action is now hidden (and a bug in
    score restoration was fixed); the game is now responsive, and
    proposing to change speed was now mostly useless; and multiple
    game sizes are now proposed when you click on the New Game
    button (including a 3 by 3). Also, the game can now be played
    with gestures (and with WASD keys). About technical things, the
    application changed to use the org.gnome.TwentyFortyEight
    app-id, and it can be built using the Gitlab CI.
  + Updated translations.
- Drop libxml2-tools and perl(XML::Parser) BuildRequires: No longer
  needed, nor used.
* Wed Jan  9 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + On the UI side, the migration from an app-menu to a hamburger
    menu is done. And on the technical side, the migration to Meson
    is done also.
  + Updated translations.
- Switch to meson buildsystem, add meson BuildRequires and macros.
- Drop intltool BuildRequires, no longer needed.
* Fri Sep  7 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Some Gitlab-migration-related.
  + Updated translations.
- Add autosetup and make_build macros, build it properly.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Oct  2 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Updated translations.
- Drop %%glib2_gsettings_schema_* post/postun and
  %%glib2_gsettings_schema_requires macros: functionality now
  covered by file triggers.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + AppData fixes.
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + A simple technical update (dependency renamed).
  + Updated translations.
- Replace pkgconfig(libgnome-games-support-1.0) with
  pkgconfig(libgnome-games-support-1) BuildRequires following
  upstream changes.
* Thu Aug 18 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Some small technical updates, including metadatas.
- Replace pkgconfig(libgames-support-1.0) for
  pkgconfig(libgnome-games-support-1.0) BuildRequires following
  upstream changes.
* Mon May  9 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Bugs fixed: bgo#765825.
* Thu Apr 14 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Updated translations.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + New hires icon.
  + Updated translations.
* Wed Feb 17 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + +Changes for this release are mainly some code cleanings.
- Changes from version 3.19.4:
  + Make new game work in if game does not exist.
  + Fixed new game glitch.
  + Stop using deprecated gnome-common.
  + Add pre-commit and pre-applypatch hooks.
  + Fixed congrat message.
  + Undo score changes with undo.
  + Disable undo on new game.
  + Updated translations.
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Updated translations.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fix starting game for the first time.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Updated translations.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Adapt to libgames-support .pc name change.
  + libgames-support now has an API-versioned vapi file.
  + Show window after creating scores dialog.
  + Dynamically set version in about dialog.
  + Updated translations.
- Replace pkgconfig(libgames-support) for
  pkgconfig(libgames-support-1.0) BuildRequires due to name change.
* Wed Jun 24 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Initial tarball release.
  + Updated translations.
- Drop gnome-common and NOCONFIGURE call, bootstraping no longer
  needed as we are using a tarball release now.
- Add intltool, itstool and libxml2-tools BuildRequires: They were
  pulled in by gnome-common before.
* Wed Jun 24 2015 dimstar@opensuse.org
- Own %%{_datadir}/appdata for openSUSE 42.
* Mon Mar 30 2015 dimstar@opensuse.org
- Initial package, based on git snapshot (no release available
  yet).
